@@ -10,7 +10,7 @@ from pathlib import Path
 from typing import TYPE_CHECKING, Iterator
 
 from duty import duty
-from duty.callables import black, coverage, lazy, mkdocs, mypy, pytest, ruff, safety
+from duty.callables import coverage, lazy, mkdocs, mypy, pytest, ruff, safety
 
 if TYPE_CHECKING:
     from duty.context import Context
@@ -22,7 +22,7 @@ PY_SRC = " ".join(PY_SRC_LIST)
 CI = os.environ.get("CI", "0") in {"1", "true", "yes", ""}
 WINDOWS = os.name == "nt"
 PTY = not WINDOWS and not CI
-MULTIRUN = os.environ.get("PDM_MULTIRUN", "0") == "1"
+MULTIRUN = os.environ.get("MULTIRUN", "0") == "1"
 
 
 def pyprefix(title: str) -> str:  # noqa: D103
@@ -88,15 +88,15 @@ def check_dependencies(ctx: Context) -> None:
     """
     # retrieve the list of dependencies
     requirements = ctx.run(
-        ["pdm", "export", "-f", "requirements", "--without-hashes"],
-        title="Exporting dependencies as requirements",
+        ["uv", "pip", "freeze"],
+        silent=True,
         allow_overrides=False,
     )
 
     ctx.run(
         safety.check(requirements),
         title="Checking dependencies",
-        command="pdm export -f requirements --without-hashes | safety check --stdin",
+        command="uv pip freeze | safety check --stdin",
     )
 
 
@@ -157,17 +157,17 @@ def clean(ctx: Context) -> None:
     Parameters:
         ctx: The context instance (passed automatically).
     """
-    ctx.run("rm -rf .coverage*")
-    ctx.run("rm -rf .mypy_cache")
-    ctx.run("rm -rf .pytest_cache")
-    ctx.run("rm -rf tests/.pytest_cache")
-    ctx.run("rm -rf build")
-    ctx.run("rm -rf dist")
-    ctx.run("rm -rf htmlcov")
-    ctx.run("rm -rf pip-wheel-metadata")
-    ctx.run("rm -rf site")
-    ctx.run("find . -type d -name __pycache__ | xargs rm -rf")
-    ctx.run("find . -name '*.rej' -delete")
+
+    def _rm(*targets: str) -> None:
+        for target in targets:
+            ctx.run(f"rm -rf {target}")
+
+    def _find_rm(*targets: str) -> None:
+        for target in targets:
+            ctx.run(f"find . -type d -name '{target}' | xargs rm -rf")
+
+    _rm("build", "dist", ".coverage*", "htmlcov", "site", ".pdm-build")
+    _find_rm(".cache", ".pytest_cache", ".mypy_cache", ".ruff_cache", "__pycache__")
 
 
 @duty
@@ -228,7 +228,7 @@ def format(ctx: Context) -> None:
         ruff.check(*PY_SRC_LIST, config="config/ruff.toml", fix_only=True, exit_zero=True),
         title="Auto-fixing code",
     )
-    ctx.run(black.run(*PY_SRC_LIST, config="config/black.toml"), title="Formatting code")
+    ctx.run(ruff.format(*PY_SRC_LIST, config="config/ruff.toml"), title="Formatting code")
 
 
 @duty(post=["docs-deploy"])
@@ -250,7 +250,7 @@ def release(ctx: Context, version: str) -> None:
     ctx.run(f"git tag {version}", title="Tagging commit", pty=PTY)
     ctx.run("git push", title="Pushing commits", pty=False)
     ctx.run("git push --tags", title="Pushing tags", pty=False)
-    ctx.run("pdm build", title="Building dist/wheel", pty=PTY)
+    ctx.run("pyproject-build", title="Building dist/wheel", pty=PTY)
     ctx.run("twine upload --skip-existing dist/*", title="Publishing version", pty=PTY)
 
 
