@@ -1,7 +1,7 @@
 """This module holds the code of the Markdown extension responsible for matching "autodoc" instructions.
 
 The extension is composed of a Markdown [block processor](https://python-markdown.github.io/extensions/api/#blockparser)
-that matches indented blocks starting with a line like '::: identifier'.
+that matches indented blocks starting with a line like `::: identifier`.
 
 For each of these blocks, it uses a [handler][mkdocstrings.handlers.base.BaseHandler] to collect documentation about
 the given identifier and render it with Jinja templates.
@@ -228,7 +228,7 @@ class AutoDocProcessor(BlockProcessor):
         return rendered, handler, data
 
 
-class _PostProcessor(Treeprocessor):
+class _HeadingsPostProcessor(Treeprocessor):
     def run(self, root: Element) -> None:
         self._remove_duplicated_headings(root)
 
@@ -249,6 +249,17 @@ class _PostProcessor(Treeprocessor):
             parent.text = (parent.text or "") + carry_text
 
 
+class _TocLabelsTreeProcessor(Treeprocessor):
+    def run(self, root: Element) -> None:  # noqa: ARG002
+        self._override_toc_labels(self.md.toc_tokens)  # type: ignore[attr-defined]
+
+    def _override_toc_labels(self, tokens: list[dict[str, Any]]) -> None:
+        for token in tokens:
+            if (label := token.get("data-toc-label")) and token["name"] != label:
+                token["name"] = label
+                self._override_toc_labels(token["children"])
+
+
 class MkdocstringsExtension(Extension):
     """Our Markdown extension.
 
@@ -284,7 +295,12 @@ class MkdocstringsExtension(Extension):
             priority=75,  # Right before markdown.blockprocessors.HashHeaderProcessor
         )
         md.treeprocessors.register(
-            _PostProcessor(md),
-            "mkdocstrings_post",
+            _HeadingsPostProcessor(md),
+            "mkdocstrings_post_headings",
+            priority=4,  # Right after 'toc'.
+        )
+        md.treeprocessors.register(
+            _TocLabelsTreeProcessor(md),
+            "mkdocstrings_post_toc_labels",
             priority=4,  # Right after 'toc'.
         )
